NeMo NLP Collection: Neural Modules for Natural Language Processing
===================================================================

**Models**

    * Neural Machine Translation
    * BERT
    * Intent Classification and Slot filling
    * Named Entity Recognition

See the documentation and tutorials for ``nemo_nlp`` [here](https://nvidia.github.io/NeMo/nlp/intro.html).